@@ -36,6 +36,7 @@
 #include "mainwindow.h"
 
 #include <KAboutData>
+#include <KDBusService>
 #include <KCrash>
 #include <KLocalizedString>
 
@@ -56,7 +57,7 @@ int main(int argc, char *argv[])
     global_debug = 0;
 
     QApplication application(argc, argv);
-    KLocalizedString::setApplicationDomain("lskat");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("lskat"));
 
     KAboutData aboutData(QStringLiteral("lskat"), i18n("LSkat"),
                           QStringLiteral(LSKAT_VERSION_STRING),
@@ -87,6 +88,7 @@ int main(int argc, char *argv[])
     /* command line handling */
 
     KCrash::initialize();
+    KDBusService service;
 
     // Check for debug command line option
     if (parser.isSet(QStringLiteral("debug")))
